---
title: Pipeline CLI Intro
---

# The Dynamically Generated Snk CLI

The primary feature of Snk is dynamic CLI generation. Many aspects of this CLI can be configure though the [Snk config file](/snk_config_file/). 

The CLI provides several commands for interacting with the pipeline including 

- config - Access the pipeline configuration.
- [env](/CLI/env/) - Access the pipeline conda environments.
- [script](/CLI/script/) - Access the pipeline scripts.
- info - Display information about the pipeline.
- profile - Access the pipeline profiles.
- run - Run the Snakemake pipeline.
